//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu> 
// Creation Date: 18 December 1997
// Last Modified: Sun Jan 25 15:31:49 GMT-0800 1998
// Filename:      ...sig/code/control/MidiInput/MidiInput.cpp
// Web Address:   http://www-ccrma.stanford.edu/~craig/improv/src/MidiInput.cpp
// Syntax:        C++
//
// Description:   A higher-level MIDI input interface than the 
//                MidiInPort class.  Can be used to allow multiple
//                objects to share a single MIDI input stream, or
//                to fake a MIDI input connection.
//

#include "MidiInput.h"
#include <stdlib.h>
#include <iostream.h>


//////////////////////////////
//
// MidiInput::MidiInput -- opens the specified MIDI input device and
//    sets the size of the input buffer.
//

MidiInput::MidiInput(void) : MidiInPort() {
   orphanBuffer = NULL;
}


MidiInput::MidiInput(int aPort, int autoOpen) : MidiInPort(aPort, autoOpen) {
   orphanBuffer = NULL;
}



//////////////////////////////
//
// MidiInput::~MidiInput
//

MidiInput::~MidiInput() {
   if (orphanBuffer != NULL) {
      delete orphanBuffer;
      orphanBuffer = NULL;
   }
}



//////////////////////////////
//
// MidiInput::getBufferSize 
//

int MidiInput::getBufferSize(void) {
   if (isOrphan()) {
      return orphanBuffer->getSize();
   } else {
      return MidiInPort::getBufferSize();
   }
}



//////////////////////////////
//
// MidiInput::getCount
//

int MidiInput::getCount(void) {
   if (isOrphan()) {
      return orphanBuffer->getCount();
   } else {
      return MidiInPort::getCount();
   }
}



//////////////////////////////
//
// MidiInput::extract
//

MidiMessage MidiInput::extract(void) {
   if (isOrphan()) {
      return orphanBuffer->extract();
   } else {
      return MidiInPort::extract();
   }
}



//////////////////////////////
//
// MidiInput::insert
//

void MidiInput::insert(const MidiMessage& aMessage) {
   if (isOrphan()) {
      orphanBuffer->insert(aMessage);
   } else {
      MidiInPort::insert(aMessage);
   }
}



//////////////////////////////
//
// MidiInput::isOrphan
//

int MidiInput::isOrphan(void) const {
   if (orphanBuffer == NULL) {
      return 0;
   } else {
      return 1;
   }
}



//////////////////////////////
//
// MidiInput::makeOrphanBuffer
//     default value: aSize = 1024
//

void MidiInput::makeOrphanBuffer(int aSize) {
   if (!isOrphan()) {
      if (orphanBuffer == NULL) {
         delete orphanBuffer;
         orphanBuffer = NULL;
      }
      orphanBuffer = new CircularBuffer<MidiMessage>(aSize);
   }
}



//////////////////////////////
//
// MidiInput::removeOrphanBuffer
//

void MidiInput::removeOrphanBuffer(void) {
   if (isOrphan()) {
      delete orphanBuffer;
      orphanBuffer = NULL;
   }
}



//////////////////////////////
//
// MidiInput::setBufferSize
//

void MidiInput::setBufferSize(int aSize) {
   if (isOrphan()) {
      orphanBuffer->setSize(aSize);
   } else {
      MidiInPort::setBufferSize(aSize);
   }
}   






// md5sum:        72ebfb07be1622dfc60e6f7f15a388c3  MidiInput.cpp
